# frozen_string_literal: true

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Auto-generated by gapic-generator-ruby. DO NOT EDIT!


module Google
  module Cloud
    module PolicyTroubleshooter
      module V1
        # Information about the member, resource, and permission to check.
        # @!attribute [rw] principal
        #   @return [::String]
        #     Required. The member, or principal, whose access you want to check, in the form of
        #     the email address that represents that member. For example,
        #     `alice@example.com` or
        #     `my-service-account@my-project.iam.gserviceaccount.com`.
        #
        #     The member must be a Google Account or a service account. Other types of
        #     members are not supported.
        # @!attribute [rw] full_resource_name
        #   @return [::String]
        #     Required. The full resource name that identifies the resource. For example,
        #     `//compute.googleapis.com/projects/my-project/zones/us-central1-a/instances/my-instance`.
        #
        #     For examples of full resource names for Google Cloud services, see
        #     https://cloud.google.com/iam/help/troubleshooter/full-resource-names.
        # @!attribute [rw] permission
        #   @return [::String]
        #     Required. The IAM permission to check for the specified member and resource.
        #
        #     For a complete list of IAM permissions, see
        #     https://cloud.google.com/iam/help/permissions/reference.
        #
        #     For a complete list of predefined IAM roles and the permissions in each
        #     role, see https://cloud.google.com/iam/help/roles/reference.
        class AccessTuple
          include ::Google::Protobuf::MessageExts
          extend ::Google::Protobuf::MessageExts::ClassMethods
        end

        # Details about how a specific IAM {::Google::Iam::V1::Policy Policy} contributed
        # to the access check.
        # @!attribute [rw] access
        #   @return [::Google::Cloud::PolicyTroubleshooter::V1::AccessState]
        #     Indicates whether _this policy_ provides the specified permission to the
        #     specified member for the specified resource.
        #
        #     This field does _not_ indicate whether the member actually has the
        #     permission for the resource. There might be another policy that overrides
        #     this policy. To determine whether the member actually has the permission,
        #     use the `access` field in the
        #     [TroubleshootIamPolicyResponse][IamChecker.TroubleshootIamPolicyResponse].
        # @!attribute [rw] full_resource_name
        #   @return [::String]
        #     The full resource name that identifies the resource. For example,
        #     `//compute.googleapis.com/projects/my-project/zones/us-central1-a/instances/my-instance`.
        #
        #     If the sender of the request does not have access to the policy, this field
        #     is omitted.
        #
        #     For examples of full resource names for Google Cloud services, see
        #     https://cloud.google.com/iam/help/troubleshooter/full-resource-names.
        # @!attribute [rw] policy
        #   @return [::Google::Iam::V1::Policy]
        #     The IAM policy attached to the resource.
        #
        #     If the sender of the request does not have access to the policy, this field
        #     is empty.
        # @!attribute [rw] binding_explanations
        #   @return [::Array<::Google::Cloud::PolicyTroubleshooter::V1::BindingExplanation>]
        #     Details about how each binding in the policy affects the member's ability,
        #     or inability, to use the permission for the resource.
        #
        #     If the sender of the request does not have access to the policy, this field
        #     is omitted.
        # @!attribute [rw] relevance
        #   @return [::Google::Cloud::PolicyTroubleshooter::V1::HeuristicRelevance]
        #     The relevance of this policy to the overall determination in the
        #     [TroubleshootIamPolicyResponse][IamChecker.TroubleshootIamPolicyResponse].
        #
        #     If the sender of the request does not have access to the policy, this field
        #     is omitted.
        class ExplainedPolicy
          include ::Google::Protobuf::MessageExts
          extend ::Google::Protobuf::MessageExts::ClassMethods
        end

        # Details about how a binding in a policy affects a member's ability to use a
        # permission.
        # @!attribute [rw] access
        #   @return [::Google::Cloud::PolicyTroubleshooter::V1::AccessState]
        #     Required. Indicates whether _this binding_ provides the specified permission to the
        #     specified member for the specified resource.
        #
        #     This field does _not_ indicate whether the member actually has the
        #     permission for the resource. There might be another binding that overrides
        #     this binding. To determine whether the member actually has the permission,
        #     use the `access` field in the
        #     [TroubleshootIamPolicyResponse][IamChecker.TroubleshootIamPolicyResponse].
        # @!attribute [rw] role
        #   @return [::String]
        #     The role that this binding grants. For example,
        #     `roles/compute.serviceAgent`.
        #
        #     For a complete list of predefined IAM roles, as well as the permissions in
        #     each role, see https://cloud.google.com/iam/help/roles/reference.
        # @!attribute [rw] role_permission
        #   @return [::Google::Cloud::PolicyTroubleshooter::V1::BindingExplanation::RolePermission]
        #     Indicates whether the role granted by this binding contains the specified
        #     permission.
        # @!attribute [rw] role_permission_relevance
        #   @return [::Google::Cloud::PolicyTroubleshooter::V1::HeuristicRelevance]
        #     The relevance of the permission's existence, or nonexistence, in the role
        #     to the overall determination for the entire policy.
        # @!attribute [rw] memberships
        #   @return [::Google::Protobuf::Map{::String => ::Google::Cloud::PolicyTroubleshooter::V1::BindingExplanation::AnnotatedMembership}]
        #     Indicates whether each member in the binding includes the member specified
        #     in the request, either directly or indirectly. Each key identifies a member
        #     in the binding, and each value indicates whether the member in the binding
        #     includes the member in the request.
        #
        #     For example, suppose that a binding includes the following members:
        #
        #     * `user:alice@example.com`
        #     * `group:product-eng@example.com`
        #
        #     You want to troubleshoot access for `user:bob@example.com`. This user is a
        #     member of the group `group:product-eng@example.com`.
        #
        #     For the first member in the binding, the key is `user:alice@example.com`,
        #     and the `membership` field in the value is set to
        #     `MEMBERSHIP_NOT_INCLUDED`.
        #
        #     For the second member in the binding, the key is
        #     `group:product-eng@example.com`, and the `membership` field in the value is
        #     set to `MEMBERSHIP_INCLUDED`.
        # @!attribute [rw] relevance
        #   @return [::Google::Cloud::PolicyTroubleshooter::V1::HeuristicRelevance]
        #     The relevance of this binding to the overall determination for the entire
        #     policy.
        # @!attribute [rw] condition
        #   @return [::Google::Type::Expr]
        #     A condition expression that prevents access unless the expression evaluates
        #     to `true`.
        #
        #     To learn about IAM Conditions, see
        #     http://cloud.google.com/iam/help/conditions/overview.
        class BindingExplanation
          include ::Google::Protobuf::MessageExts
          extend ::Google::Protobuf::MessageExts::ClassMethods

          # Details about whether the binding includes the member.
          # @!attribute [rw] membership
          #   @return [::Google::Cloud::PolicyTroubleshooter::V1::BindingExplanation::Membership]
          #     Indicates whether the binding includes the member.
          # @!attribute [rw] relevance
          #   @return [::Google::Cloud::PolicyTroubleshooter::V1::HeuristicRelevance]
          #     The relevance of the member's status to the overall determination for the
          #     binding.
          class AnnotatedMembership
            include ::Google::Protobuf::MessageExts
            extend ::Google::Protobuf::MessageExts::ClassMethods
          end

          # @!attribute [rw] key
          #   @return [::String]
          # @!attribute [rw] value
          #   @return [::Google::Cloud::PolicyTroubleshooter::V1::BindingExplanation::AnnotatedMembership]
          class MembershipsEntry
            include ::Google::Protobuf::MessageExts
            extend ::Google::Protobuf::MessageExts::ClassMethods
          end

          # Whether a role includes a specific permission.
          module RolePermission
            # Reserved for future use.
            ROLE_PERMISSION_UNSPECIFIED = 0

            # The permission is included in the role.
            ROLE_PERMISSION_INCLUDED = 1

            # The permission is not included in the role.
            ROLE_PERMISSION_NOT_INCLUDED = 2

            # The sender of the request is not allowed to access the binding.
            ROLE_PERMISSION_UNKNOWN_INFO_DENIED = 3
          end

          # Whether the binding includes the member.
          module Membership
            # Reserved for future use.
            MEMBERSHIP_UNSPECIFIED = 0

            # The binding includes the member. The member can be included directly
            # or indirectly. For example:
            #
            # * A member is included directly if that member is listed in the binding.
            # * A member is included indirectly if that member is in a Google group or
            #   G Suite domain that is listed in the binding.
            MEMBERSHIP_INCLUDED = 1

            # The binding does not include the member.
            MEMBERSHIP_NOT_INCLUDED = 2

            # The sender of the request is not allowed to access the binding.
            MEMBERSHIP_UNKNOWN_INFO_DENIED = 3

            # The member is an unsupported type. Only Google Accounts and service
            # accounts are supported.
            MEMBERSHIP_UNKNOWN_UNSUPPORTED = 4
          end
        end

        # Whether a member has a permission for a resource.
        module AccessState
          # Reserved for future use.
          ACCESS_STATE_UNSPECIFIED = 0

          # The member has the permission.
          GRANTED = 1

          # The member does not have the permission.
          NOT_GRANTED = 2

          # The member has the permission only if a condition expression evaluates to
          # `true`.
          UNKNOWN_CONDITIONAL = 3

          # The sender of the request does not have access to all of the policies that
          # Policy Troubleshooter needs to evaluate.
          UNKNOWN_INFO_DENIED = 4
        end

        # The extent to which a single data point contributes to an overall
        # determination.
        module HeuristicRelevance
          # Reserved for future use.
          HEURISTIC_RELEVANCE_UNSPECIFIED = 0

          # The data point has a limited effect on the result. Changing the data point
          # is unlikely to affect the overall determination.
          NORMAL = 1

          # The data point has a strong effect on the result. Changing the data point
          # is likely to affect the overall determination.
          HIGH = 2
        end
      end
    end
  end
end
